/*
 * Return a filtered single ToF value from a packet burst.
 *
 * A burst consists of an array of ToF and RSSI values measured back-to-back
 * on a single frequency as well as a timestamp in seconds.
 *
 * This example discards the highest and lowest values and takes an average.
 *
 * @param curFrame - {freq: 2402, tofs: [583,..], rssis: [-46,..], ts: 30.3402}
 * @return 'frame.filtered_bust_tof'
 */
(function filterBurst(freq, frames, curFrame)
{
    // Remove invalid ToF samples, either no-sync or failed challenge response
    var samples = curFrame.tofs.filter(function(v){ return v>0; });
    // Filter the valid samples
    return samples
        .sort(function(a,b){return a-b})    // Comment out to not sort
        .slice(32, -32)                     // Take from sample N to min(M, max)
        .reduce(function(acc, cur, idx, arr) {
            return acc + cur/arr.length;    // Average
            //return (acc>cur)?cur:acc; // Use minimum (remove ', 0' below)
        }, 0);
});
