/*
 * Return a filtered single ToF value for the time series.
 *
 * Uses as input the already filtered burst to apply for example a low-pass
 * filter on the time-series.
 *
 * @param curFrame - {.. , filtered_burst_tof: 586.3211,
 * @param frames   - [{.. , filtered_tof: 585.21 [not in curFrame] }]
 * @return 'frame.filtered_tof'
 */
(function filterSeries(curFrame, frames)
{
    // For this frame we only have the filtered burst so far
    var cur = curFrame.filtered_burst_tof;

    // Get the previous frame
    var prevFrame = frames.slice(-2,-1)[0];
    // If this is the first sample, there is no previous frame
    if (prevFrame === undefined) return cur;
    // The previous frame has a time-filtered value
    var prev = prevFrame.filtered_tof;

    // Filter strength [0..1]. Lower places less weight on current measurement.
    var beta = 0.3;

    // Return weighed against previous. Since this is 'prev' for the next
    // filter iteration, it is a recursive filter.
    return cur*beta + prev*(1-beta);
});
